@@ -1011,6 +1011,16 @@ InstanceTypeType = Literal[
     "c6i.large",
     "c6i.metal",
     "c6i.xlarge",
+    "c6id.12xlarge",
+    "c6id.16xlarge",
+    "c6id.24xlarge",
+    "c6id.2xlarge",
+    "c6id.32xlarge",
+    "c6id.4xlarge",
+    "c6id.8xlarge",
+    "c6id.large",
+    "c6id.metal",
+    "c6id.xlarge",
     "c7g.12xlarge",
     "c7g.16xlarge",
     "c7g.2xlarge",
@@ -1238,6 +1248,16 @@ InstanceTypeType = Literal[
     "m6i.large",
     "m6i.metal",
     "m6i.xlarge",
+    "m6id.12xlarge",
+    "m6id.16xlarge",
+    "m6id.24xlarge",
+    "m6id.2xlarge",
+    "m6id.32xlarge",
+    "m6id.4xlarge",
+    "m6id.8xlarge",
+    "m6id.large",
+    "m6id.metal",
+    "m6id.xlarge",
     "mac1.metal",
     "mac2.metal",
     "p2.16xlarge",
@@ -1248,6 +1268,7 @@ InstanceTypeType = Literal[
     "p3.8xlarge",
     "p3dn.24xlarge",
     "p4d.24xlarge",
+    "p4de.24xlarge",
     "r3.2xlarge",
     "r3.4xlarge",
     "r3.8xlarge",
@@ -1320,6 +1341,17 @@ InstanceTypeType = Literal[
     "r5n.large",
     "r5n.metal",
     "r5n.xlarge",
+    "r6a.12xlarge",
+    "r6a.16xlarge",
+    "r6a.24xlarge",
+    "r6a.2xlarge",
+    "r6a.32xlarge",
+    "r6a.48xlarge",
+    "r6a.4xlarge",
+    "r6a.8xlarge",
+    "r6a.large",
+    "r6a.metal",
+    "r6a.xlarge",
     "r6g.12xlarge",
     "r6g.16xlarge",
     "r6g.2xlarge",
@@ -1348,6 +1380,16 @@ InstanceTypeType = Literal[
     "r6i.large",
     "r6i.metal",
     "r6i.xlarge",
+    "r6id.12xlarge",
+    "r6id.16xlarge",
+    "r6id.24xlarge",
+    "r6id.2xlarge",
+    "r6id.32xlarge",
+    "r6id.4xlarge",
+    "r6id.8xlarge",
+    "r6id.large",
+    "r6id.metal",
+    "r6id.xlarge",
     "t1.micro",
     "t2.2xlarge",
     "t2.large",
@@ -1526,7 +1568,7 @@ LocalGatewayRouteTypeType = Literal["propagated", "static"]
 LocalStorageType = Literal["excluded", "included", "required"]
 LocalStorageTypeType = Literal["hdd", "ssd"]
 LocationTypeType = Literal["availability-zone", "availability-zone-id", "region"]
-LogDestinationTypeType = Literal["cloud-watch-logs", "s3"]
+LogDestinationTypeType = Literal["cloud-watch-logs", "kinesis-data-firehose", "s3"]
 MarketTypeType = Literal["spot"]
 MembershipTypeType = Literal["igmp", "static"]
 ModifyAvailabilityZoneOptInStatusType = Literal["not-opted-in", "opted-in"]
@@ -1697,6 +1739,7 @@ ResourceTypeType = Literal[
     "vpc-flow-log",
     "vpc-peering-connection",
     "vpn-connection",
+    "vpn-connection-device-type",
     "vpn-gateway",
 ]
 RootDeviceTypeType = Literal["ebs", "instance-store"]
@@ -1904,6 +1947,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -1946,6 +1990,7 @@ ServiceName = Literal[
     "connect-contact-lens",
     "connectcampaigns",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -2103,6 +2148,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -2165,6 +2211,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
@@ -2377,6 +2424,7 @@ RegionName = Literal[
     "eu-west-1",
     "eu-west-2",
     "eu-west-3",
+    "me-central-1",
     "me-south-1",
     "sa-east-1",
     "us-east-1",
